import { Module, Provider } from '@nestjs/common';
import { CqrsModule } from '@nestjs/cqrs';
import { GetConfigurationGrpcController } from './interface/grpc-controllers/get-configuration.grpc.controller';
import { SetConfigurationGrpcController } from './interface/grpc-controllers/set-configuration.grpc.controller';
import { SetConfigurationService } from './core/application/commands/set-configuration/set-configuration.service';
import { GetConfigurationQueryHandler } from './core/application/queries/get-configuration/get-configuration.query-handler';
import { ConfigurationMapper } from './configuration.mapper';
import { CONFIGURATION_REPOSITORY } from './configuration.di-tokens';
import { PopulateService } from './core/application/services/populate.service';
import { ConfigurationRepository } from '@mobicoop/configuration-module';
import { ConfigurationsManagerService } from './core/application/services/configurations-manager.service';

const grpcControllers = [
  GetConfigurationGrpcController,
  SetConfigurationGrpcController,
];

const commandHandlers: Provider[] = [SetConfigurationService];

const queryHandlers: Provider[] = [GetConfigurationQueryHandler];

const mappers: Provider[] = [ConfigurationMapper];

const providers: Provider[] = [PopulateService, ConfigurationsManagerService];

const repositories: Provider[] = [
  {
    provide: CONFIGURATION_REPOSITORY,
    useClass: ConfigurationRepository,
  },
];

@Module({
  imports: [CqrsModule],
  controllers: [...grpcControllers],
  providers: [
    ...commandHandlers,
    ...queryHandlers,
    ...mappers,
    ...providers,
    ...repositories,
  ],
  exports: [ConfigurationMapper, CONFIGURATION_REPOSITORY],
})
export class ConfigurationModule {}
