import { Module, Provider } from '@nestjs/common';
import { MESSAGE_PUBLISHER } from './messager.di-tokens';

import { ConfigModule, ConfigService } from '@nestjs/config';
import { SERVICE_NAME } from '@src/app.constants';
import {
  MessageBrokerModule,
  MessageBrokerModuleOptions,
  MessageBrokerPublisher,
} from '@mobicoop/message-broker-module';

const imports = [
  MessageBrokerModule.forRootAsync({
    imports: [ConfigModule],
    inject: [ConfigService],
    useFactory: async (
      configService: ConfigService,
    ): Promise<MessageBrokerModuleOptions> => ({
      uri: configService.get<string>('broker.uri') as string,
      exchange: {
        name: configService.get<string>('broker.exchange') as string,
        durable: configService.get<boolean>('broker.durability') as boolean,
      },
      name: SERVICE_NAME,
    }),
  }),
];

const providers: Provider[] = [
  {
    provide: MESSAGE_PUBLISHER,
    useClass: MessageBrokerPublisher,
  },
];

@Module({
  imports,
  providers,
  exports: [MESSAGE_PUBLISHER],
})
export class MessagerModule {}
